<?php

declare(strict_types=1);

/**
 * @copyright Copyright (c) 2024 Sagar Gurung <sagar@jankaritech.com>
 *
 * @author Sagar Gurung <sagar@jankaritech.com>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */


namespace OCA\Nepenthes\Listener;

use OCA\Nepenthes\AppInfo\Application;
use OCA\Nepenthes\Service\NepenthesAPIService;
use OCA\TermsOfService\Events\SignaturesResetEvent;
use OCA\TermsOfService\Events\TermsCreatedEvent;
use OCP\App\Events\AppEnableEvent;
use OCP\DB\Exception as DBException;
use OCP\EventDispatcher\Event;
use OCP\EventDispatcher\IEventListener;
use Psr\Log\LoggerInterface;

/**
 * @template-implements IEventListener<Event>
 */
class TermsOfServiceEventListener implements IEventListener {

	/**
	 * @var NepenthesAPIService
	 */
	private NepenthesAPIService $openprojectAPIService;

	/**
	 * @var LoggerInterface
	 */
	private $logger;

	public function __construct(
		NepenthesAPIService $openprojectAPIService,
		LoggerInterface $logger
	) {
		$this->openprojectAPIService = $openprojectAPIService;
		$this->logger = $logger;
	}

	public function handle(Event $event): void {
		try {
			if ($event instanceof TermsCreatedEvent) {
				$this->openprojectAPIService->signTermsOfServiceForUserOpenProject();
			}
			if ($event instanceof SignaturesResetEvent) {
				$this->openprojectAPIService->signTermsOfServiceForUserOpenProject();
			}
			if ($event instanceof AppEnableEvent) {
				if ($event->getAppId() === 'terms_of_service') {
					$this->openprojectAPIService->signTermsOfServiceForUserOpenProject();
				}
			}
		} catch (DBException $e) {
			$this->logger->error(
				'Error: ' . $e->getMessage(),
				['app' => Application::APP_ID]
			);
		}
	}
}
